import 'dart:convert';

import 'package:comunic/models/login_tokens.dart';
import 'package:shared_preferences/shared_preferences.dart';

/// Preferences helper
///
/// Stores current account tokens
///
/// @author Pierre HUBERT

enum PreferencesKeyList { LOGIN_TOKENS }

const _PreferenceKeysName = {PreferencesKeyList.LOGIN_TOKENS: "login_tokens"};

class PreferencesHelper {
  static PreferencesHelper _instance;

  static Future<PreferencesHelper> getInstance() async {
    if (_instance == null) {
      _instance = PreferencesHelper._();
      await _init();
    }

    return _instance;
  }

  static SharedPreferences _sharedPreferences;

  PreferencesHelper._();

  static Future<void> _init() async {
    _sharedPreferences = await SharedPreferences.getInstance();
  }

  /// Set new login tokens
  Future<void> setLoginTokens(LoginTokens tokens) async {
    await setString(PreferencesKeyList.LOGIN_TOKENS,
        tokens == null ? "null" : tokens.toString());
  }

  /// Get current [LoginTokens]. Returns null if none or in case of failure
  LoginTokens getLoginTokens() {
    try {
      final string = getString(PreferencesKeyList.LOGIN_TOKENS);
      if (string == null || string == "null") return null;
      return LoginTokens.fromJSON(jsonDecode(string));
    } on Exception catch (e) {
      print(e.toString());
      return null;
    }
  }

  Future<void> setString(PreferencesKeyList key, String value) async {
    await _sharedPreferences.setString(_PreferenceKeysName[key], value);
  }

  String getString(PreferencesKeyList key) {
    return _sharedPreferences.getString(_PreferenceKeysName[key]);
  }
}
